pub struct BlockInfo {
    pub block_number: u64,
    pub block_timestamp: u64,
    pub gas_price: u128,
    pub sequencer_address: Address,
}

Fields

block_number: u64

The sequence number of the last block created.

block_timestamp: u64

Timestamp of the beginning of the last block creation attempt.

gas_price: u128

L1 gas price (in Wei) measured at the beginning of the last block creation attempt.

sequencer_address: Address

The sequencer address of this block.

Implementations

source

impl BlockInfo

source

pub const fn empty(sequencer_address: Address) -> Self